@@ -59,17 +59,22 @@ def do_the_radicale_dance(tmpdir):
     import radicale.config
 
     # Now we can set some basic configuration.
-    radicale.config.set('rights', 'type', 'owner_only')
-    radicale.config.set('auth', 'type', 'http')
+    # Radicale <=0.7 doesn't work with this, therefore we just catch the
+    # exception and assume Radicale is open for everyone.
+    try:
+        radicale.config.set('rights', 'type', 'owner_only')
+        radicale.config.set('auth', 'type', 'http')
 
-    import radicale.auth.http
+        import radicale.auth.http
 
-    def is_authenticated(user, password):
-        return user == 'bob' and password == 'bob'
-    radicale.auth.http.is_authenticated = is_authenticated
+        def is_authenticated(user, password):
+            return user == 'bob' and password == 'bob'
+        radicale.auth.http.is_authenticated = is_authenticated
+    except Exception as e:
+        print(e)
 
-    if storage_backend == 'filesystem':
-        radicale.config.set('storage', 'type', 'filesystem')
+    if storage_backend in ('filesystem', 'multifilesystem'):
+        radicale.config.set('storage', 'type', storage_backend)
         radicale.config.set('storage', 'filesystem_folder', tmpdir)
     elif storage_backend == 'database':
         radicale.config.set('storage', 'type', 'database')
@@ -81,7 +86,7 @@ def do_the_radicale_dance(tmpdir):
             s.execute(line)
         s.commit()
     else:
-        raise RuntimeError()
+        raise RuntimeError(storage_backend)
 
 
 class ServerMixin(object):
@@ -99,10 +104,13 @@ class ServerMixin(object):
             wsgi_intercept.requests_intercept.uninstall()
         request.addfinalizer(teardown)
 
-    def get_storage_args(self, collection='test'):
-        url = 'http://127.0.0.1/bob/'
-        if collection is not None:
-            collection += self.storage_class.fileext
+    @pytest.fixture
+    def get_storage_args(self):
+        def inner(collection='test'):
+            url = 'http://127.0.0.1/bob/'
+            if collection is not None:
+                collection += self.storage_class.fileext
 
-        return {'url': url, 'username': 'bob', 'password': 'bob',
-                'collection': collection, 'unsafe_href_chars': ''}
+            return {'url': url, 'username': 'bob', 'password': 'bob',
+                    'collection': collection, 'unsafe_href_chars': ''}
+        return inner
